#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 polysemy
version:              1.9.2.0
visibility:           public
id:                   polysemy-1.9.2.0-19EmOzI7vxq448tGgJMIfO
key:                  polysemy-1.9.2.0-19EmOzI7vxq448tGgJMIfO
license:              BSD-3-Clause
copyright:            2019-2023 The Polysemy Lounge
maintainer:
    https://funprog.zulipchat.com/#narrow/stream/216942-Polysemy

author:               Sandy Maguire
homepage:             https://github.com/polysemy-research/polysemy#readme
synopsis:             Higher-order, low-boilerplate free monads.
description:
    Please see the README on GitHub at <https://github.com/polysemy-research/polysemy#readme>

category:             Language
abi:                  952d791ac60c798b8ab5be9b1edacf24
exposed:              True
exposed-modules:
    Polysemy Polysemy.Async Polysemy.AtomicState Polysemy.Bundle
    Polysemy.Embed Polysemy.Embed.Type Polysemy.Error Polysemy.Fail
    Polysemy.Fail.Type Polysemy.Final Polysemy.Fixpoint Polysemy.IO
    Polysemy.Input Polysemy.Internal Polysemy.Internal.Bundle
    Polysemy.Internal.Combinators Polysemy.Internal.CustomErrors
    Polysemy.Internal.CustomErrors.Redefined Polysemy.Internal.Fixpoint
    Polysemy.Internal.Index Polysemy.Internal.Kind
    Polysemy.Internal.NonDet Polysemy.Internal.Scoped
    Polysemy.Internal.Sing Polysemy.Internal.Strategy
    Polysemy.Internal.TH.Common Polysemy.Internal.TH.Effect
    Polysemy.Internal.Tactics Polysemy.Internal.Union
    Polysemy.Internal.Writer Polysemy.Membership Polysemy.NonDet
    Polysemy.Opaque Polysemy.Output Polysemy.Reader Polysemy.Resource
    Polysemy.Scoped Polysemy.State Polysemy.Tagged Polysemy.Trace
    Polysemy.Writer

hidden-modules:       Polysemy.Internal.PluginLookup Paths_polysemy
import-dirs:          /usr/lib/ghc-9.6.6/site-local/polysemy-1.9.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/polysemy-1.9.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/polysemy-1.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polysemy
hs-libraries:         HSpolysemy-1.9.2.0-19EmOzI7vxq448tGgJMIfO
depends:
    async-2.2.6-FyNZXdji95t98VleCj3HXu base-4.18.2.1 containers-0.6.7
    first-class-families-0.8.2.0-HzUnQisuAnjGuL9m7M0Ger mtl-2.3.1
    stm-2.5.1.0 syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE
    template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3 transformers-0.6.1.0
    type-errors-0.2.0.2-12F334AO0pf41Ic358sPJj
    unagi-chan-0.4.1.4-8ekypvyzEG1DcCAm0h5zIy

haddock-interfaces:   /usr/share/doc/haskell-polysemy/html/polysemy.haddock
haddock-html:         /usr/share/doc/haskell-polysemy/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

